#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2020-11-08 21:29:00
# @Author  : Dengpan Fu (t-defu@microsoft.com)

import os
import numpy as np
import matplotlib.pyplot as plt

start = 1
ratio = [0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0]
labels = ['LUPnl.pnl.', 'LUP.unsup.', 'IN.sup.']

plot_lw    = 2
plot_fs    = 19
legend_fs  = 18
xy_fs      = 25
tick_fs    = 20
plot_alpha = 1.

color_lws  = '#CC6600'
color_lsup = '#336699' 
color_img  = '#CCCC33'


# mAP for market
mgn_map_img  = [0, 67.7, 0, 79.0, 0, 83.2, 0, 85.9, 0, 87.5]
mgn_map_lsup = [0, 76.9, 0, 84.1, 0, 87.8, 0, 89.8, 0, 91.0]
mgn_map_lws  = [0, 81.7, 0, 87.3, 0, 89.6, 0, 90.9, 0, 91.9]

ide_map_img  = [0, 41.8, 0, 55.7, 0, 63.7, 0, 69.3, 0, 74.1]
ide_map_lsup = [0, 49.9, 0, 62.0, 0, 70.3, 0, 74.2, 0, 78.0]
ide_map_lws  = [0, 57.6, 0, 70.5, 0, 77.9, 0, 80.1, 0, 82.4]


""" for MGN """
plt.figure(1, figsize=(6,4))

plt.plot(ratio[start::2], mgn_map_lws[start::2], '--*', color=color_lws, linewidth=plot_lw, alpha=plot_alpha)
for x, y in zip(ratio[start::2], mgn_map_lws[start::2]):
    plt.text(x-0.04, y+0.3, f"{y:.1f}", va='bottom', fontsize=plot_fs, color=color_lws, alpha=plot_alpha)

plt.plot(ratio[start::2], mgn_map_lsup[start::2], '--^', color=color_lsup, linewidth=plot_lw, alpha=plot_alpha)
for x, y in zip(ratio[start::2], mgn_map_lsup[start::2]):
    plt.text(x-0.04, y-3.0, f"{y:.1f}", va='bottom', fontsize=plot_fs, color=color_lsup, alpha=plot_alpha)

plt.plot(ratio[start::2], mgn_map_img[start::2], '--o', color=color_img, linewidth=plot_lw, alpha=plot_alpha)
plt.text(ratio[1]-0.035, mgn_map_img[1]+1, f"{mgn_map_img[1]:.1f}", va='bottom', fontsize=plot_fs, color=color_img, alpha=plot_alpha)
for x, y in zip(ratio[start::2][1:], mgn_map_img[start::2][1:]):
    plt.text(x-0.035, y-3.5, f"{y:.1f}", va='bottom', fontsize=plot_fs, color=color_img, alpha=plot_alpha)

plt.legend(labels, loc=[0.53, 0.01], fontsize=legend_fs)
plt.xlabel('scale', fontsize=xy_fs)
plt.ylabel('mAP(%)', fontsize=xy_fs)
plt.gca().set_xticks([0.2, 0.4, 0.6, 0.8, 1.0])
plt.gca().set_xticklabels(['20%', '40%', '60%', '80%', '100%'], fontsize=tick_fs)
xticks = [65, 70, 75, 80, 85, 90]
plt.gca().set_yticks(xticks)
plt.gca().set_yticklabels(xticks, fontsize=tick_fs)
plt.grid(b=False)
plt.grid(b=True, linewidth=1.0, axis='y', color='darkgray')
plt.gca().spines['bottom'].set_linewidth(1.5)
plt.gca().spines['bottom'].set_color('black')
plt.gca().spines['left'].set_linewidth(1.5)
plt.gca().spines['left'].set_color('black')
plt.gca().spines['top'].set_visible(False)
plt.gca().spines['right'].set_visible(False)
plt.savefig('market_mgn.png', bbox_inches='tight')

""" for IDE """
plt.figure(2, figsize=(6,4))
plt.plot(ratio[start::2], ide_map_lws[start::2], '-.x', color=color_lws, linewidth=plot_lw, alpha=plot_alpha)
plt.text(ratio[1]-0.035, ide_map_lws[1]+2.5, f"{ide_map_lws[1]:.1f}", va='bottom', fontsize=plot_fs, color=color_lws, alpha=plot_alpha)
for x, y in zip(ratio[start::2][1:], ide_map_lws[start::2][1:]):
    plt.text(x-0.06, y+0.5, f"{y:.1f}", va='bottom', fontsize=plot_fs, color=color_lws, alpha=plot_alpha)

plt.plot(ratio[start::2], ide_map_lsup[start::2], '-.<', color=color_lsup, linewidth=plot_lw, alpha=plot_alpha)
plt.text(ratio[1]-0.035, ide_map_lsup[1]+2.7, f"{ide_map_lsup[1]:.1f}", va='bottom', fontsize=plot_fs, color=color_lsup, alpha=plot_alpha)
for x, y in zip(ratio[start::2][1:], ide_map_lsup[start::2][1:]):
    plt.text(x-0.07, y-0.2, f"{y:.1f}", va='bottom', fontsize=plot_fs, color=color_lsup, alpha=plot_alpha)

plt.plot(ratio[start::2], ide_map_img[start::2], '-.>', color=color_img, linewidth=plot_lw, alpha=plot_alpha)
plt.text(ratio[1]-0.035, ide_map_img[1]+2.3, f"{ide_map_img[1]:.1f}", va='bottom', fontsize=plot_fs, color=color_img, alpha=plot_alpha)
for x, y in zip(ratio[start::2][1:], ide_map_img[start::2][1:]):
    plt.text(x-0.06, y-5.5, f"{y:.1f}", va='bottom', fontsize=plot_fs, color=color_img, alpha=plot_alpha)

plt.legend(labels, loc=[0.53, 0.01], fontsize=legend_fs)
plt.xlabel('scale', fontsize=xy_fs)
plt.ylabel('mAP(%)', fontsize=xy_fs)
plt.gca().set_xticks([0.2, 0.4, 0.6, 0.8, 1.0])
plt.gca().set_xticklabels(['20%', '40%', '60%', '80%', '100%'], fontsize=tick_fs)
xticks = [40, 50, 60, 70, 80]
plt.gca().set_yticks(xticks)
plt.gca().set_yticklabels(xticks, fontsize=tick_fs)
plt.grid(b=False)
plt.grid(b=True, linewidth=1.0, axis='y', color='darkgray')
plt.gca().spines['bottom'].set_linewidth(1.5)
plt.gca().spines['bottom'].set_color('black')
plt.gca().spines['left'].set_linewidth(1.5)
plt.gca().spines['left'].set_color('black')
plt.gca().spines['top'].set_visible(False)
plt.gca().spines['right'].set_visible(False)
plt.savefig('market_ide.png', bbox_inches='tight')